## Change Log
All notable changes to this project will be documented in this file.
This project adheres to [Semantic Versioning](http://semver.org/).

### [1.0.1] - 2015-07-11
- Fixed atom module and host-meta files by correctly including templates/ subdir.

### [1.0] - 2015-07-10
Initial release on PyPI!
